import { Component, OnInit } from '@angular/core';
import { HORIZON, SALES } from './data';
import { colors, shades } from '../../globals';

@Component({
  selector: 'app-chart-page',
  templateUrl: './chart-page.component.html',
  styleUrls: ['./chart-page.component.scss']
})
export class ChartPageComponent implements OnInit {
  activeTab:number = 0;
  brushes:string[] = [];
  compareTimePeriods:string[] = HORIZON;
  designProcess:{ [key:string]:string[] };
  designs:string[] = [];
  filter:string[] = [];
  multipleScenarios:boolean = true;
  outData1:any[] = [];
  outData2:any[] = [];
  outDataAll:any[] = [];
  outlines:string[] = [];
  parameterData:any[] = SALES;
  processes:any[] = [];
  scenario1:string = 'PLAN_2021_51';
  scenario2:string = 'BETA_2021_51_CS';
  scenarios:string[] = ['PLAN_2021_51'];

  ngOnInit(): void {
    this.parameterData.forEach((d) => {
      if (this.designs.indexOf(d.Design) < 0 && d.Design !== undefined) { this.designs.push(d.Design); }
      if (this.processes.indexOf(d.Process) < 0 && d.Process !== undefined) { this.processes.push(d.Process); }
    });
  };

  itemSelected(e:any) {
    this.activeTab = e;
    if (e === 1) { this.buildOutData('Design'); }
    else if (e === 2) { this.buildOutData('Process'); }
  };

  buildOutData(step:string) {
    let scen1Data: any[] = this.parameterData.filter((d) => d.Scenario === this.scenario1 && d.Design !== undefined),
        scen2Data: any[] = this.parameterData.filter((d) => d.Scenario === this.scenario2 && d.Design !== undefined);
    this.outData1 = [], this.outData2 = [], this.brushes = [], this.outlines = [], this.designProcess = {}, this.scenarios = [ this.scenario1 ];

    scen1Data.forEach((d, j) => {
      let filter:string = d[step], color:string = colors[this.processes.indexOf(d.Process) % 10];
      this.compareTimePeriods.forEach((p, i) => {
        let out1:number = scen2Data[j][p] > 0 ? scen2Data[j][p] : 0, out2:number = d[p] > 0 ? d[p] : 0;

        if (this.outData1[i] === undefined) { this.outData1[i] = { Date: p }; }

        if (filter in this.outData1[i]) { this.outData1[i][filter] += out1; }
        else {
          this.outData1[i][filter] = out1;
          if (step === 'Process' && !(d.Process in this.designProcess)) {
            this.brushes.push(shades[color][2]);
            this.outlines.push(shades[color][0]);
            this.designProcess[d.Process] = [''];
          } else if (step === 'Design') {
            if (d.Process in this.designProcess) {
              if (this.designProcess[d.Process].indexOf(d.Design) < 0) {
                let shadeIndex:number = this.designProcess[d.Process].length % 10;
                this.brushes.push(shades[color][shadeIndex]);
                this.outlines.push(shades[color][shadeIndex > 4 ? shadeIndex - 3 : shadeIndex + 2]);
                this.designProcess[d.Process].push(d.Design);
              }
            } else {
              this.brushes.push(shades[color][0]);
              this.outlines.push(shades[color][2]);
              this.designProcess[d.Process] = [d.Design];
            }
          }
        }

        if (this.multipleScenarios) {
          if (this.outData2[i] === undefined) { this.outData2[i] = { Date: p }; }
          if (filter in this.outData2[i]) { this.outData2[i][filter] += out2; }
          else { this.outData2[i][filter] = out2; }
        }
      });
    });
    this.outDataAll.push(this.outData1);
    if (this.multipleScenarios) {
      this.outDataAll.push(this.outData2);
      this.scenarios.push(this.scenario2);
    }

    if (step === 'Design') { this.filter = this.designs; }
    else { this.filter = this.processes; }
  };

  rebuildOutData() { this.itemSelected(this.activeTab); };
};
